@@ -9,14 +9,14 @@ from .datasets.kd_image_folder import KDImageFolder
 # transforms
 from .transforms import BYOLTransform0, BYOLTransform1
 from .transforms import MAEFinetuneTransform
+from .transforms.norm.kd_cifar100_norm import KDCifar100Norm
 # norm
 from .transforms.norm.kd_cifar10_norm import KDCifar10Norm
-from .transforms.norm.kd_cifar100_norm import KDCifar100Norm
 from .transforms.norm.kd_image_net_norm import KDImageNetNorm
 # wrappers
 from .wrappers import (
-    BYOLMultiViewWrapper,
+    ByolMultiViewWrapper,
     ImagenetMinaugMultiViewWrapper,
     ImagenetMinaugXTransformWrapper,
     ImagenetNoaugXTransformWrapper,
-)
\ No newline at end of file
+)
