@@ -1,4 +1,4 @@
-from .byol_multi_view_wrapper import BYOLMultiViewWrapper
+from .byol_multi_view_wrapper import ByolMultiViewWrapper
 from .imagenet_minaug_multi_view_wrapper import ImagenetMinaugMultiViewWrapper
 from .imagenet_minaug_x_transform_wrapper import ImagenetMinaugXTransformWrapper
-from .imagenet_noaug_x_transform_wrapper import ImagenetNoaugXTransformWrapper
\ No newline at end of file
+from .imagenet_noaug_x_transform_wrapper import ImagenetNoaugXTransformWrapper
